pub type IMXAttributes = *mut ::core::ffi::c_void;
pub type IMXNamespaceManager = *mut ::core::ffi::c_void;
pub type IMXNamespacePrefixes = *mut ::core::ffi::c_void;
pub type IMXReaderControl = *mut ::core::ffi::c_void;
pub type IMXSchemaDeclHandler = *mut ::core::ffi::c_void;
pub type IMXWriter = *mut ::core::ffi::c_void;
pub type IMXXMLFilter = *mut ::core::ffi::c_void;
pub type ISAXAttributes = *mut ::core::ffi::c_void;
pub type ISAXContentHandler = *mut ::core::ffi::c_void;
pub type ISAXDTDHandler = *mut ::core::ffi::c_void;
pub type ISAXDeclHandler = *mut ::core::ffi::c_void;
pub type ISAXEntityResolver = *mut ::core::ffi::c_void;
pub type ISAXErrorHandler = *mut ::core::ffi::c_void;
pub type ISAXLexicalHandler = *mut ::core::ffi::c_void;
pub type ISAXLocator = *mut ::core::ffi::c_void;
pub type ISAXXMLFilter = *mut ::core::ffi::c_void;
pub type ISAXXMLReader = *mut ::core::ffi::c_void;
pub type ISchema = *mut ::core::ffi::c_void;
pub type ISchemaAny = *mut ::core::ffi::c_void;
pub type ISchemaAttribute = *mut ::core::ffi::c_void;
pub type ISchemaAttributeGroup = *mut ::core::ffi::c_void;
pub type ISchemaComplexType = *mut ::core::ffi::c_void;
pub type ISchemaElement = *mut ::core::ffi::c_void;
pub type ISchemaIdentityConstraint = *mut ::core::ffi::c_void;
pub type ISchemaItem = *mut ::core::ffi::c_void;
pub type ISchemaItemCollection = *mut ::core::ffi::c_void;
pub type ISchemaModelGroup = *mut ::core::ffi::c_void;
pub type ISchemaNotation = *mut ::core::ffi::c_void;
pub type ISchemaParticle = *mut ::core::ffi::c_void;
pub type ISchemaStringCollection = *mut ::core::ffi::c_void;
pub type ISchemaType = *mut ::core::ffi::c_void;
pub type IServerXMLHTTPRequest = *mut ::core::ffi::c_void;
pub type IServerXMLHTTPRequest2 = *mut ::core::ffi::c_void;
pub type IVBMXNamespaceManager = *mut ::core::ffi::c_void;
pub type IVBSAXAttributes = *mut ::core::ffi::c_void;
pub type IVBSAXContentHandler = *mut ::core::ffi::c_void;
pub type IVBSAXDTDHandler = *mut ::core::ffi::c_void;
pub type IVBSAXDeclHandler = *mut ::core::ffi::c_void;
pub type IVBSAXEntityResolver = *mut ::core::ffi::c_void;
pub type IVBSAXErrorHandler = *mut ::core::ffi::c_void;
pub type IVBSAXLexicalHandler = *mut ::core::ffi::c_void;
pub type IVBSAXLocator = *mut ::core::ffi::c_void;
pub type IVBSAXXMLFilter = *mut ::core::ffi::c_void;
pub type IVBSAXXMLReader = *mut ::core::ffi::c_void;
pub type IXMLAttribute = *mut ::core::ffi::c_void;
pub type IXMLDOMAttribute = *mut ::core::ffi::c_void;
pub type IXMLDOMCDATASection = *mut ::core::ffi::c_void;
pub type IXMLDOMCharacterData = *mut ::core::ffi::c_void;
pub type IXMLDOMComment = *mut ::core::ffi::c_void;
pub type IXMLDOMDocument = *mut ::core::ffi::c_void;
pub type IXMLDOMDocument2 = *mut ::core::ffi::c_void;
pub type IXMLDOMDocument3 = *mut ::core::ffi::c_void;
pub type IXMLDOMDocumentFragment = *mut ::core::ffi::c_void;
pub type IXMLDOMDocumentType = *mut ::core::ffi::c_void;
pub type IXMLDOMElement = *mut ::core::ffi::c_void;
pub type IXMLDOMEntity = *mut ::core::ffi::c_void;
pub type IXMLDOMEntityReference = *mut ::core::ffi::c_void;
pub type IXMLDOMImplementation = *mut ::core::ffi::c_void;
pub type IXMLDOMNamedNodeMap = *mut ::core::ffi::c_void;
pub type IXMLDOMNode = *mut ::core::ffi::c_void;
pub type IXMLDOMNodeList = *mut ::core::ffi::c_void;
pub type IXMLDOMNotation = *mut ::core::ffi::c_void;
pub type IXMLDOMParseError = *mut ::core::ffi::c_void;
pub type IXMLDOMParseError2 = *mut ::core::ffi::c_void;
pub type IXMLDOMParseErrorCollection = *mut ::core::ffi::c_void;
pub type IXMLDOMProcessingInstruction = *mut ::core::ffi::c_void;
pub type IXMLDOMSchemaCollection = *mut ::core::ffi::c_void;
pub type IXMLDOMSchemaCollection2 = *mut ::core::ffi::c_void;
pub type IXMLDOMSelection = *mut ::core::ffi::c_void;
pub type IXMLDOMText = *mut ::core::ffi::c_void;
pub type IXMLDSOControl = *mut ::core::ffi::c_void;
pub type IXMLDocument = *mut ::core::ffi::c_void;
pub type IXMLDocument2 = *mut ::core::ffi::c_void;
pub type IXMLElement = *mut ::core::ffi::c_void;
pub type IXMLElement2 = *mut ::core::ffi::c_void;
pub type IXMLElementCollection = *mut ::core::ffi::c_void;
pub type IXMLError = *mut ::core::ffi::c_void;
pub type IXMLHTTPRequest = *mut ::core::ffi::c_void;
pub type IXMLHTTPRequest2 = *mut ::core::ffi::c_void;
pub type IXMLHTTPRequest2Callback = *mut ::core::ffi::c_void;
pub type IXMLHTTPRequest3 = *mut ::core::ffi::c_void;
pub type IXMLHTTPRequest3Callback = *mut ::core::ffi::c_void;
pub type IXMLHttpRequest = *mut ::core::ffi::c_void;
pub type IXSLProcessor = *mut ::core::ffi::c_void;
pub type IXSLTemplate = *mut ::core::ffi::c_void;
pub type IXTLRuntime = *mut ::core::ffi::c_void;
pub type XMLDOMDocumentEvents = *mut ::core::ffi::c_void;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ATTRIBUTE: u32 = 117u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ATTRIBUTE_GETNAME: u32 = 118u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ATTRIBUTE_SPECIFIED: u32 = 119u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ATTRIBUTE_VALUE: u32 = 120u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ATTRIBUTE__TOP: u32 = 121u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_BASE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_COLLECTION_BASE: u32 = 1000000u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_COLLECTION_MAX: u32 = 2999999u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA: u32 = 108u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA_APPEND: u32 = 112u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA_DATA: u32 = 109u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA_DELETE: u32 = 114u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA_INSERT: u32 = 113u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA_LENGTH: u32 = 110u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA_REPLACE: u32 = 115u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA_SUBSTRING: u32 = 111u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DATA__TOP: u32 = 116u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT: u32 = 37u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENTFRAGMENT: u32 = 94u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENTFRAGMENT__TOP: u32 = 95u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENTTYPE: u32 = 130u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENTTYPE_ENTITIES: u32 = 132u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENTTYPE_NAME: u32 = 131u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENTTYPE_NOTATIONS: u32 = 133u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENTTYPE__TOP: u32 = 134u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATEATTRIBUTE: u32 = 47u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATECDATASECTION: u32 = 45u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATECOMMENT: u32 = 44u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATEDOCUMENTFRAGMENT: u32 = 42u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATEELEMENT: u32 = 41u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATEENTITY: u32 = 48u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATEENTITYREFERENCE: u32 = 49u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATEPROCESSINGINSTRUCTION: u32 = 46u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_CREATETEXTNODE: u32 = 43u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_DOCTYPE: u32 = 38u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_DOCUMENTELEMENT: u32 = 40u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_GETELEMENTSBYTAGNAME: u32 = 50u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_IMPLEMENTATION: u32 = 39u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_DOCUMENT_TOP: u32 = 51u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT: u32 = 96u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_GETATTRIBUTE: u32 = 99u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_GETATTRIBUTENODE: u32 = 102u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_GETATTRIBUTES: u32 = 98u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_GETELEMENTSBYTAGNAME: u32 = 105u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_GETTAGNAME: u32 = 97u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_NORMALIZE: u32 = 106u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_REMOVEATTRIBUTE: u32 = 101u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_REMOVEATTRIBUTENODE: u32 = 104u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_SETATTRIBUTE: u32 = 100u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT_SETATTRIBUTENODE: u32 = 103u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ELEMENT__TOP: u32 = 107u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ENTITY: u32 = 139u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ENTITY_NOTATIONNAME: u32 = 142u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ENTITY_PUBLICID: u32 = 140u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ENTITY_SYSTEMID: u32 = 141u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ENTITY__TOP: u32 = 143u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR: u32 = 177u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR2: u32 = 186u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR2_ALLERRORS: u32 = 187u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR2_ERRORPARAMETERS: u32 = 188u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR2_ERRORPARAMETERSCOUNT: u32 = 189u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR2_ERRORXPATH: u32 = 190u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR2__TOP: u32 = 191u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERRORCOLLECTION: u32 = 192u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERRORCOLLECTION_LENGTH: u32 = 193u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERRORCOLLECTION_NEXT: u32 = 194u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERRORCOLLECTION_RESET: u32 = 195u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERRORCOLLECTION__TOP: u32 = 196u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR_ERRORCODE: u32 = 178u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR_FILEPOS: u32 = 184u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR_LINE: u32 = 182u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR_LINEPOS: u32 = 183u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR_REASON: u32 = 180u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR_SRCTEXT: u32 = 181u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR_URL: u32 = 179u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_ERROR__TOP: u32 = 185u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_IMPLEMENTATION: u32 = 144u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_IMPLEMENTATION_HASFEATURE: u32 = 145u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_IMPLEMENTATION__TOP: u32 = 146u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NAMEDNODEMAP: u32 = 80u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NAMEDNODEMAP_GETNAMEDITEM: u32 = 83u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NAMEDNODEMAP_REMOVENAMEDITEM: u32 = 85u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NAMEDNODEMAP_SETNAMEDITEM: u32 = 84u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODELIST: u32 = 72u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODELIST_ITEM: u32 = 73u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODELIST_LENGTH: u32 = 74u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_APPENDCHILD: u32 = 16u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_ATTRIBUTES: u32 = 12u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_CHILDNODES: u32 = 7u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_CLONENODE: u32 = 19u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_FIRSTCHILD: u32 = 8u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_HASCHILDNODES: u32 = 17u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_INSERTBEFORE: u32 = 13u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_LASTCHILD: u32 = 9u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_NEXTSIBLING: u32 = 11u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_NODENAME: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_NODETYPE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_NODETYPEENUM: u32 = 5u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_NODEVALUE: u32 = 3u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_OWNERDOC: u32 = 18u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_PARENTNODE: u32 = 6u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_PREVIOUSSIBLING: u32 = 10u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_REMOVECHILD: u32 = 15u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NODE_REPLACECHILD: u32 = 14u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NOTATION: u32 = 135u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NOTATION_PUBLICID: u32 = 136u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NOTATION_SYSTEMID: u32 = 137u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_NOTATION__TOP: u32 = 138u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_PI: u32 = 126u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_PI_DATA: u32 = 128u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_PI_TARGET: u32 = 127u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_PI__TOP: u32 = 129u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_TEXT: u32 = 122u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_TEXT_JOINTEXT: u32 = 124u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_TEXT_SPLITTEXT: u32 = 123u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_TEXT__TOP: u32 = 125u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_W3CWRAPPERS: u32 = 93u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM_W3CWRAPPERS_TOP: u32 = 143u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_DOM__TOP: u32 = 176u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER: u32 = 1418u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_CONTENTHANDLER: u32 = 1419u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_DTDHANDLER: u32 = 1420u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_ENTITYRESOLVER: u32 = 1421u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_ERRORHANDLER: u32 = 1422u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_GETFEATURE: u32 = 1423u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_GETPROPERTY: u32 = 1424u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_PUTFEATURE: u32 = 1425u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER_PUTPROPERTY: u32 = 1426u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER__BASE: u32 = 1418u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MXXML_FILTER__TOP: u32 = 1427u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES: u32 = 1372u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_ADDATTRIBUTE: u32 = 1373u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_ADDATTRIBUTEFROMINDEX: u32 = 1383u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_CLEAR: u32 = 1374u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_REMOVEATTRIBUTE: u32 = 1375u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_SETATTRIBUTE: u32 = 1376u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_SETATTRIBUTES: u32 = 1377u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_SETLOCALNAME: u32 = 1378u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_SETQNAME: u32 = 1379u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_SETTYPE: u32 = 1380u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_SETURI: u32 = 1381u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES_SETVALUE: u32 = 1382u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES__BASE: u32 = 1372u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_ATTRIBUTES__TOP: u32 = 1383u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR: u32 = 1405u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_ALLOWOVERRIDE: u32 = 1406u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_DECLAREPREFIX: u32 = 1411u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_GETDECLAREDPREFIXES: u32 = 1412u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_GETPREFIXES: u32 = 1413u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_GETURI: u32 = 1414u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_GETURIFROMNODE: u32 = 1415u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_LENGTH: u32 = 1416u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_POPCONTEXT: u32 = 1410u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_PUSHCONTEXT: u32 = 1408u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_PUSHNODECONTEXT: u32 = 1409u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR_RESET: u32 = 1407u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR__BASE: u32 = 1405u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_NSMGR__TOP: u32 = 1417u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_READER_CONTROL: u32 = 1397u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_READER_CONTROL_ABORT: u32 = 1398u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_READER_CONTROL_RESUME: u32 = 1399u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_READER_CONTROL_SUSPEND: u32 = 1400u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_READER_CONTROL__BASE: u32 = 1397u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_READER_CONTROL__TOP: u32 = 1401u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_SCHEMADECLHANDLER: u32 = 1402u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_SCHEMADECLHANDLER_SCHEMAELEMENTDECL: u32 = 1403u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_SCHEMADECLHANDLER__BASE: u32 = 1402u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_SCHEMADECLHANDLER__TOP: u32 = 1404u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER: u32 = 1384u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_BYTEORDERMARK: u32 = 1388u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_DESTINATION: u32 = 1386u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_DISABLEOUTPUTESCAPING: u32 = 1393u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_ENCODING: u32 = 1387u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_FLUSH: u32 = 1394u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_INDENT: u32 = 1389u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_OMITXMLDECLARATION: u32 = 1391u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_OUTPUT: u32 = 1385u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_RESET: u32 = 1395u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_STANDALONE: u32 = 1390u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER_VERSION: u32 = 1392u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER__BASE: u32 = 1384u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_MX_WRITER__TOP: u32 = 1396u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE: u32 = 66036u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST: u32 = 66136u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST_CURRENT: u32 = 66139u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST_ITEM: u32 = 66143u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST_LENGTH: u32 = 66142u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST_MOVE: u32 = 66140u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST_MOVETONODE: u32 = 66141u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST_NEWENUM: u32 = 66137u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODELIST_NEXT: u32 = 66138u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_ADD: u32 = 66045u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_ATTRIBUTES: u32 = 66044u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_CHILDREN: u32 = 66047u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_GETATTRIBUTE: u32 = 66042u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_NAME: u32 = 66037u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_PARENT: u32 = 66038u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_REMOVE: u32 = 66046u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_REMOVEATTRIBUTE: u32 = 66043u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_SETATTRIBUTE: u32 = 66041u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_TYPE: u32 = 66039u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_NODE_VALUE: u32 = 66040u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES: u32 = 1343u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETINDEXFROMNAME: u32 = 1348u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETINDEXFROMQNAME: u32 = 1349u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETLOCALNAME: u32 = 1346u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETQNAME: u32 = 1347u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETTYPE: u32 = 1350u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETTYPEFROMNAME: u32 = 1351u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETTYPEFROMQNAME: u32 = 1352u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETURI: u32 = 1345u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETVALUE: u32 = 1353u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETVALUEFROMNAME: u32 = 1354u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_GETVALUEFROMQNAME: u32 = 1355u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES_LENGTH: u32 = 1344u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES__BASE: u32 = 1343u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ATTRIBUTES__TOP: u32 = 1356u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER: u32 = 1321u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_CHARACTERS: u32 = 1329u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_DOCUMENTLOCATOR: u32 = 1322u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_ENDDOCUMENT: u32 = 1324u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_ENDELEMENT: u32 = 1328u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_ENDPREFIXMAPPING: u32 = 1326u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_IGNORABLEWHITESPACE: u32 = 1330u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_PROCESSINGINSTRUCTION: u32 = 1331u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_SKIPPEDENTITY: u32 = 1332u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_STARTDOCUMENT: u32 = 1323u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_STARTELEMENT: u32 = 1327u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER_STARTPREFIXMAPPING: u32 = 1325u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER__BASE: u32 = 1321u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_CONTENTHANDLER__TOP: u32 = 1333u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DECLHANDLER: u32 = 1366u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DECLHANDLER_ATTRIBUTEDECL: u32 = 1368u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DECLHANDLER_ELEMENTDECL: u32 = 1367u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DECLHANDLER_EXTERNALENTITYDECL: u32 = 1370u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DECLHANDLER_INTERNALENTITYDECL: u32 = 1369u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DECLHANDLER__BASE: u32 = 1366u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DECLHANDLER__TOP: u32 = 1371u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DTDHANDLER: u32 = 1334u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DTDHANDLER_NOTATIONDECL: u32 = 1335u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DTDHANDLER_UNPARSEDENTITYDECL: u32 = 1336u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DTDHANDLER__BASE: u32 = 1334u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_DTDHANDLER__TOP: u32 = 1337u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ENTITYRESOLVER: u32 = 1318u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ENTITYRESOLVER_RESOLVEENTITY: u32 = 1319u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ENTITYRESOLVER__BASE: u32 = 1318u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ENTITYRESOLVER__TOP: u32 = 1320u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ERRORHANDLER: u32 = 1338u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ERRORHANDLER_ERROR: u32 = 1339u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ERRORHANDLER_FATALERROR: u32 = 1340u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ERRORHANDLER_IGNORABLEWARNING: u32 = 1341u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ERRORHANDLER__BASE: u32 = 1338u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_ERRORHANDLER__TOP: u32 = 1342u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER: u32 = 1357u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER_COMMENT: u32 = 1364u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER_ENDCDATA: u32 = 1363u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER_ENDDTD: u32 = 1359u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER_ENDENTITY: u32 = 1361u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER_STARTCDATA: u32 = 1362u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER_STARTDTD: u32 = 1358u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER_STARTENTITY: u32 = 1360u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER__BASE: u32 = 1357u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LEXICALHANDLER__TOP: u32 = 1365u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LOCATOR: u32 = 1312u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LOCATOR_COLUMNNUMBER: u32 = 1313u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LOCATOR_LINENUMBER: u32 = 1314u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LOCATOR_PUBLICID: u32 = 1315u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LOCATOR_SYSTEMID: u32 = 1316u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LOCATOR__BASE: u32 = 1312u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_LOCATOR__TOP: u32 = 1317u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER: u32 = 1296u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_BASEURL: u32 = 1305u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_CONTENTHANDLER: u32 = 1302u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_DTDHANDLER: u32 = 1303u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_ENTITYRESOLVER: u32 = 1301u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_ERRORHANDLER: u32 = 1304u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_GETFEATURE: u32 = 1297u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_GETPROPERTY: u32 = 1299u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_PARENT: u32 = 1309u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_PARSE: u32 = 1307u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_PARSEURL: u32 = 1308u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_PUTFEATURE: u32 = 1298u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_PUTPROPERTY: u32 = 1300u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER_SECUREBASEURL: u32 = 1306u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER__BASE: u32 = 1296u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLFILTER__TOP: u32 = 1311u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER: u32 = 1281u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_BASEURL: u32 = 1290u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_CONTENTHANDLER: u32 = 1287u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_DTDHANDLER: u32 = 1288u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_ENTITYRESOLVER: u32 = 1286u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_ERRORHANDLER: u32 = 1289u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_GETFEATURE: u32 = 1282u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_GETPROPERTY: u32 = 1284u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_PARENT: u32 = 1294u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_PARSE: u32 = 1292u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_PARSEURL: u32 = 1293u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_PUTFEATURE: u32 = 1283u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_PUTPROPERTY: u32 = 1285u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER_SECUREBASEURL: u32 = 1291u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER__BASE: u32 = 1281u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER__MAX: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER__MIN: u32 = 1281u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SAX_XMLREADER__TOP: u32 = 1295u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM: u32 = 1418u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ANYATTRIBUTE: u32 = 1425u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ATTRIBUTEGROUPS: u32 = 1426u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ATTRIBUTES: u32 = 1427u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_BASETYPES: u32 = 1428u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_CONTENTMODEL: u32 = 1429u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_CONTENTTYPE: u32 = 1430u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_DEFAULTVALUE: u32 = 1431u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_DERIVEDBY: u32 = 1432u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_DISALLOWED: u32 = 1433u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ELEMENTS: u32 = 1434u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ENUMERATION: u32 = 1435u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_EXCLUSIONS: u32 = 1472u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_FIELDS: u32 = 1436u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_FINAL: u32 = 1437u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_FIXEDVALUE: u32 = 1438u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_FRACTIONDIGITS: u32 = 1439u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_GETDECLARATION: u32 = 1422u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_GETSCHEMA: u32 = 1421u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ID: u32 = 1440u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_IDCONSTRAINTS: u32 = 1441u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ISABSTRACT: u32 = 1442u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ISNILLABLE: u32 = 1443u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ISREFERENCE: u32 = 1444u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ISVALID: u32 = 1445u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ITEMBYNAME: u32 = 1423u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ITEMBYQNAME: u32 = 1424u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_ITEMTYPE: u32 = 1446u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_LENGTH: u32 = 1447u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MAXEXCLUSIVE: u32 = 1448u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MAXINCLUSIVE: u32 = 1449u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MAXLENGTH: u32 = 1450u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MAXOCCURS: u32 = 1451u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MINEXCLUSIVE: u32 = 1452u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MININCLUSIVE: u32 = 1453u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MINLENGTH: u32 = 1454u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MINOCCURS: u32 = 1455u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_MODELGROUPS: u32 = 1456u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_NAME: u32 = 1457u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_NAMESPACES: u32 = 1458u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_NAMESPACEURI: u32 = 1459u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_NOTATIONS: u32 = 1460u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_PARTICLES: u32 = 1461u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_PATTERNS: u32 = 1462u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_PROCESSCONTENTS: u32 = 1463u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_PROHIBITED: u32 = 1464u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_PUBLICIDENTIFIER: u32 = 1465u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_REFERENCEDKEY: u32 = 1466u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_SCHEMA: u32 = 1467u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_SCHEMALOCATIONS: u32 = 1468u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_SCOPE: u32 = 1469u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_SELECTOR: u32 = 1470u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_SUBSTITUTIONGROUP: u32 = 1471u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_SYSTEMIDENTIFIER: u32 = 1473u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_TARGETNAMESPACE: u32 = 1474u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_TOP: u32 = 1484u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_TOTALDIGITS: u32 = 1475u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_TYPE: u32 = 1476u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_TYPES: u32 = 1477u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_UNHANDLEDATTRS: u32 = 1478u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_USE: u32 = 1479u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_VALIDATE: u32 = 1419u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_VALIDATEONLOAD: u32 = 1420u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_VARIETY: u32 = 1480u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_VERSION: u32 = 1481u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_WHITESPACE: u32 = 1482u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_SOM_WRITEANNOTATION: u32 = 1483u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLATTRIBUTE: u32 = 65936u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLATTRIBUTE_NAME: u32 = 65937u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLATTRIBUTE_VALUE: u32 = 65938u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT: u32 = 65636u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_ASYNC: u32 = 65649u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_BASEURL: u32 = 65651u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_CASEINSENSITIVE: u32 = 65650u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_CHARSET: u32 = 65645u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_COMMIT: u32 = 65655u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_CREATEELEMENT: u32 = 65644u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_DOCTYPE: u32 = 65647u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_DTDURL: u32 = 65648u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_FILEMODIFIEDDATE: u32 = 65639u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_FILESIZE: u32 = 65638u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_FILEUPDATEDDATE: u32 = 65640u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_LASTERROR: u32 = 65653u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_MIMETYPE: u32 = 65642u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_READYSTATE: u32 = 65643u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_ROOT: u32 = 65637u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_TRIMWHITESPACE: u32 = 65654u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_URL: u32 = 65641u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_VERSION: u32 = 65646u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOCUMENT_XML: u32 = 65652u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOMEVENT: u32 = 197u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOMEVENT_ONDATAAVAILABLE: u32 = 198u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOMEVENT_ONREADYSTATECHANGE: i32 = -609i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOMEVENT__TOP: u32 = 199u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT: u32 = 52u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT2: u32 = 200u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT2_GETPROPERTY: u32 = 205u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT2_NAMESPACES: u32 = 201u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT2_SCHEMAS: u32 = 202u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT2_SETPROPERTY: u32 = 204u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT2_VALIDATE: u32 = 203u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT2__TOP: u32 = 206u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT3: u32 = 207u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT3_IMPORTNODE: u32 = 209u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT3_VALIDATENODE: u32 = 208u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT3__TOP: u32 = 210u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_ABORT: u32 = 62u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_ASYNC: u32 = 61u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_CREATENODE: u32 = 54u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_CREATENODEEX: u32 = 55u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_DOCUMENTNAMESPACES: u32 = 57u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_DOCUMENTNODE: u32 = 53u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_LOAD: u32 = 58u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_LOADXML: u32 = 63u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_NODEFROMID: u32 = 56u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_ONDATAAVAILABLE: u32 = 69u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_ONREADYSTATECHANGE: u32 = 68u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_ONTRANSFORMNODE: u32 = 70u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_PARSEERROR: u32 = 59u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_PRESERVEWHITESPACE: u32 = 67u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_RESOLVENAMESPACE: u32 = 66u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_SAVE: u32 = 64u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_URL: u32 = 60u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT_VALIDATE: u32 = 65u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_DOCUMENT__TOP: u32 = 71u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NAMEDNODEMAP: u32 = 86u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NAMEDNODEMAP_GETQUALIFIEDITEM: u32 = 87u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NAMEDNODEMAP_NEWENUM: u32 = 91u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NAMEDNODEMAP_NEXTNODE: u32 = 89u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NAMEDNODEMAP_REMOVEQUALIFIEDITEM: u32 = 88u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NAMEDNODEMAP_RESET: u32 = 90u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NAMEDNODEMAP__TOP: u32 = 92u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE: u32 = 20u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODELIST: u32 = 75u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODELIST_NEWENUM: u32 = 78u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODELIST_NEXTNODE: u32 = 76u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODELIST_RESET: u32 = 77u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODELIST__TOP: u32 = 79u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_BASENAME: u32 = 34u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_DATATYPE: u32 = 26u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_DEFINITION: u32 = 23u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_NAMESPACE: u32 = 32u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_NODETYPEDVALUE: u32 = 25u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_PARSED: u32 = 31u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_PREFIX: u32 = 33u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_SELECTNODES: u32 = 29u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_SELECTSINGLENODE: u32 = 30u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_SPECIFIED: u32 = 22u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_STRINGTYPE: u32 = 21u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_TEXT: u32 = 24u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_TRANSFORMNODE: u32 = 28u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_TRANSFORMNODETOOBJECT: u32 = 35u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE_XML: u32 = 27u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_NODE__TOP: u32 = 36u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_ADDOBJECT: u32 = 12u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_ADDPARAMETER: u32 = 11u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_INPUT: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_OUTPUT: u32 = 7u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_READYSTATE: u32 = 10u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_RESET: u32 = 9u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_SETSTARTMODE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_STARTMODE: u32 = 5u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_STARTMODEURI: u32 = 6u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_STYLESHEET: u32 = 13u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_TRANSFORM: u32 = 8u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR_XSLTEMPLATE: u32 = 3u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_PROCESSOR__TOP: u32 = 14u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION_ADD: u32 = 3u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION_ADDCOLLECTION: u32 = 8u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION_GET: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION_LENGTH: u32 = 6u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION_NAMESPACEURI: u32 = 7u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION_REMOVE: u32 = 5u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SCHEMACOLLECTION__TOP: u32 = 9u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION: u32 = 80u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_CLONE: u32 = 87u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_CONTEXT: u32 = 82u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_EXPR: u32 = 81u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_GETPROPERTY: u32 = 88u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_MATCHES: u32 = 84u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_PEEKNODE: u32 = 83u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_REMOVEALL: u32 = 86u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_REMOVENEXT: u32 = 85u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION_SETPROPERTY: u32 = 89u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_SELECTION__TOP: u32 = 90u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_TEMPLATE: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_TEMPLATE_CREATEPROCESSOR: u32 = 3u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_TEMPLATE_STYLESHEET: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDOM_TEMPLATE__TOP: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_CREATEKEYFROMCSP: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_CREATEKEYFROMHMACSECRET: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_CREATEKEYFROMNODE: u32 = 3u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_CREATESAXPROXY: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_GETVERIFYINGCERTIFICATE: u32 = 5u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_SETREFERENCEDATA: u32 = 6u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_SIGN: u32 = 7u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_SIGNATURE: u32 = 8u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_STORE: u32 = 9u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSIG_VERIFY: u32 = 10u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSO: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSO_DOCUMENT: u32 = 65537u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLDSO_JAVADSOCOMPATIBLE: u32 = 65538u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT: u32 = 65736u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENTCOLLECTION: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENTCOLLECTION_ITEM: u32 = 65539u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENTCOLLECTION_LENGTH: u32 = 65537u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENTCOLLECTION_NEWENUM: i32 = -4i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_ADDCHILD: u32 = 65745u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_ATTRIBUTES: u32 = 65747u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_CHILDREN: u32 = 65742u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_GETATTRIBUTE: u32 = 65740u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_PARENT: u32 = 65738u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_REMOVEATTRIBUTE: u32 = 65741u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_REMOVECHILD: u32 = 65746u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_SETATTRIBUTE: u32 = 65739u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_TAGNAME: u32 = 65737u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_TEXT: u32 = 65744u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLELEMENT_TYPE: u32 = 65743u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLERROR: u32 = 65936u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLERROR_LINE: u32 = 65938u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLERROR_POS: u32 = 65939u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLERROR_REASON: u32 = 65937u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLNOTIFSINK: u32 = 65836u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XMLNOTIFSINK_CHILDADDED: u32 = 65837u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XOBJ_BASE: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XOBJ_MAX: u32 = 131071u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XOBJ_MIN: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME: u32 = 186u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_ABSOLUTECHILDNUMBER: u32 = 191u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_ANCESTORCHILDNUMBER: u32 = 190u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_CHILDNUMBER: u32 = 189u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_DEPTH: u32 = 188u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_FORMATDATE: u32 = 194u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_FORMATINDEX: u32 = 192u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_FORMATNUMBER: u32 = 193u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_FORMATTIME: u32 = 195u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME_UNIQUEID: u32 = 187u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DISPID_XTLRUNTIME__TOP: u32 = 196u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DOMDocument: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x2933bf90_7b36_11d2_b20e_00c04f983e60);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DOMDocument60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a05_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const DOMFreeThreadedDocument: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x2933bf91_7b36_11d2_b20e_00c04f983e60);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const E_XML_BUFFERTOOSMALL: i32 = -1072897498i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const E_XML_INVALID: i32 = -1072897499i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const E_XML_NODTD: i32 = -1072897500i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const E_XML_NOTWF: i32 = -1072897501i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const FreeThreadedDOMDocument60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a06_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const FreeThreadedXMLHTTP60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a09_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const MXHTMLWriter60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a10_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const MXNamespaceManager60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a11_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const MXXMLWriter60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a0f_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SAXAttributes60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a0e_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SAXXMLReader60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a0c_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const ServerXMLHTTP60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a0b_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_ONDATA_ALWAYS: u32 = 0u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_ONDATA_NEVER: u64 = 18446744073709551615u64;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLDSOControl: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x550dda30_0541_11d2_9ca9_0060b0ec3d39);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLDocument: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xcfc399af_d876_11d0_9c10_00c04fc99c8e);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLHTTP60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a0a_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLHTTPRequest: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xed8c108e_4349_11d2_91a4_00c04f7969e8);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLSchemaCache60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a07_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XSLTemplate60: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x88d96a08_f192_11d4_a65f_0040963251e5);
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type DOMNodeType = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_INVALID: DOMNodeType = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_ELEMENT: DOMNodeType = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_ATTRIBUTE: DOMNodeType = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_TEXT: DOMNodeType = 3i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_CDATA_SECTION: DOMNodeType = 4i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_ENTITY_REFERENCE: DOMNodeType = 5i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_ENTITY: DOMNodeType = 6i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_PROCESSING_INSTRUCTION: DOMNodeType = 7i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_COMMENT: DOMNodeType = 8i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_DOCUMENT: DOMNodeType = 9i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_DOCUMENT_TYPE: DOMNodeType = 10i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_DOCUMENT_FRAGMENT: DOMNodeType = 11i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const NODE_NOTATION: DOMNodeType = 12i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SCHEMACONTENTTYPE = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMACONTENTTYPE_EMPTY: SCHEMACONTENTTYPE = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMACONTENTTYPE_TEXTONLY: SCHEMACONTENTTYPE = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMACONTENTTYPE_ELEMENTONLY: SCHEMACONTENTTYPE = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMACONTENTTYPE_MIXED: SCHEMACONTENTTYPE = 3i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SCHEMADERIVATIONMETHOD = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_EMPTY: SCHEMADERIVATIONMETHOD = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_SUBSTITUTION: SCHEMADERIVATIONMETHOD = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_EXTENSION: SCHEMADERIVATIONMETHOD = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_RESTRICTION: SCHEMADERIVATIONMETHOD = 4i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_LIST: SCHEMADERIVATIONMETHOD = 8i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_UNION: SCHEMADERIVATIONMETHOD = 16i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_ALL: SCHEMADERIVATIONMETHOD = 255i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMADERIVATIONMETHOD_NONE: SCHEMADERIVATIONMETHOD = 256i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SCHEMAPROCESSCONTENTS = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAPROCESSCONTENTS_NONE: SCHEMAPROCESSCONTENTS = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAPROCESSCONTENTS_SKIP: SCHEMAPROCESSCONTENTS = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAPROCESSCONTENTS_LAX: SCHEMAPROCESSCONTENTS = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAPROCESSCONTENTS_STRICT: SCHEMAPROCESSCONTENTS = 3i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SCHEMATYPEVARIETY = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMATYPEVARIETY_NONE: SCHEMATYPEVARIETY = -1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMATYPEVARIETY_ATOMIC: SCHEMATYPEVARIETY = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMATYPEVARIETY_LIST: SCHEMATYPEVARIETY = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMATYPEVARIETY_UNION: SCHEMATYPEVARIETY = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SCHEMAUSE = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAUSE_OPTIONAL: SCHEMAUSE = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAUSE_PROHIBITED: SCHEMAUSE = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAUSE_REQUIRED: SCHEMAUSE = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SCHEMAWHITESPACE = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAWHITESPACE_NONE: SCHEMAWHITESPACE = -1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAWHITESPACE_PRESERVE: SCHEMAWHITESPACE = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAWHITESPACE_REPLACE: SCHEMAWHITESPACE = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SCHEMAWHITESPACE_COLLAPSE: SCHEMAWHITESPACE = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SERVERXMLHTTP_OPTION = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_OPTION_URL: SERVERXMLHTTP_OPTION = -1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_OPTION_URL_CODEPAGE: SERVERXMLHTTP_OPTION = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_OPTION_ESCAPE_PERCENT_IN_URL: SERVERXMLHTTP_OPTION = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_OPTION_IGNORE_SERVER_SSL_CERT_ERROR_FLAGS: SERVERXMLHTTP_OPTION = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_OPTION_SELECT_CLIENT_SSL_CERT: SERVERXMLHTTP_OPTION = 3i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SOMITEMTYPE = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_SCHEMA: SOMITEMTYPE = 4096i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ATTRIBUTE: SOMITEMTYPE = 4097i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ATTRIBUTEGROUP: SOMITEMTYPE = 4098i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_NOTATION: SOMITEMTYPE = 4099i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ANNOTATION: SOMITEMTYPE = 4100i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_IDENTITYCONSTRAINT: SOMITEMTYPE = 4352i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_KEY: SOMITEMTYPE = 4353i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_KEYREF: SOMITEMTYPE = 4354i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_UNIQUE: SOMITEMTYPE = 4355i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ANYTYPE: SOMITEMTYPE = 8192i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE: SOMITEMTYPE = 8448i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_ANYTYPE: SOMITEMTYPE = 8449i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_ANYURI: SOMITEMTYPE = 8450i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_BASE64BINARY: SOMITEMTYPE = 8451i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_BOOLEAN: SOMITEMTYPE = 8452i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_BYTE: SOMITEMTYPE = 8453i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_DATE: SOMITEMTYPE = 8454i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_DATETIME: SOMITEMTYPE = 8455i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_DAY: SOMITEMTYPE = 8456i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_DECIMAL: SOMITEMTYPE = 8457i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_DOUBLE: SOMITEMTYPE = 8458i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_DURATION: SOMITEMTYPE = 8459i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_ENTITIES: SOMITEMTYPE = 8460i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_ENTITY: SOMITEMTYPE = 8461i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_FLOAT: SOMITEMTYPE = 8462i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_HEXBINARY: SOMITEMTYPE = 8463i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_ID: SOMITEMTYPE = 8464i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_IDREF: SOMITEMTYPE = 8465i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_IDREFS: SOMITEMTYPE = 8466i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_INT: SOMITEMTYPE = 8467i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_INTEGER: SOMITEMTYPE = 8468i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_LANGUAGE: SOMITEMTYPE = 8469i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_LONG: SOMITEMTYPE = 8470i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_MONTH: SOMITEMTYPE = 8471i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_MONTHDAY: SOMITEMTYPE = 8472i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NAME: SOMITEMTYPE = 8473i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NCNAME: SOMITEMTYPE = 8474i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NEGATIVEINTEGER: SOMITEMTYPE = 8475i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NMTOKEN: SOMITEMTYPE = 8476i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NMTOKENS: SOMITEMTYPE = 8477i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NONNEGATIVEINTEGER: SOMITEMTYPE = 8478i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NONPOSITIVEINTEGER: SOMITEMTYPE = 8479i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NORMALIZEDSTRING: SOMITEMTYPE = 8480i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_NOTATION: SOMITEMTYPE = 8481i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_POSITIVEINTEGER: SOMITEMTYPE = 8482i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_QNAME: SOMITEMTYPE = 8483i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_SHORT: SOMITEMTYPE = 8484i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_STRING: SOMITEMTYPE = 8485i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_TIME: SOMITEMTYPE = 8486i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_TOKEN: SOMITEMTYPE = 8487i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_UNSIGNEDBYTE: SOMITEMTYPE = 8488i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_UNSIGNEDINT: SOMITEMTYPE = 8489i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_UNSIGNEDLONG: SOMITEMTYPE = 8490i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_UNSIGNEDSHORT: SOMITEMTYPE = 8491i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_YEAR: SOMITEMTYPE = 8492i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_YEARMONTH: SOMITEMTYPE = 8493i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_DATATYPE_ANYSIMPLETYPE: SOMITEMTYPE = 8703i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_SIMPLETYPE: SOMITEMTYPE = 8704i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_COMPLEXTYPE: SOMITEMTYPE = 9216i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_PARTICLE: SOMITEMTYPE = 16384i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ANY: SOMITEMTYPE = 16385i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ANYATTRIBUTE: SOMITEMTYPE = 16386i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ELEMENT: SOMITEMTYPE = 16387i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_GROUP: SOMITEMTYPE = 16640i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_ALL: SOMITEMTYPE = 16641i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_CHOICE: SOMITEMTYPE = 16642i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_SEQUENCE: SOMITEMTYPE = 16643i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_EMPTYPARTICLE: SOMITEMTYPE = 16644i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_NULL: SOMITEMTYPE = 2048i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_NULL_TYPE: SOMITEMTYPE = 10240i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_NULL_ANY: SOMITEMTYPE = 18433i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_NULL_ANYATTRIBUTE: SOMITEMTYPE = 18434i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SOMITEM_NULL_ELEMENT: SOMITEMTYPE = 18435i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SXH_PROXY_SETTING = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_PROXY_SET_DEFAULT: SXH_PROXY_SETTING = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_PROXY_SET_PRECONFIG: SXH_PROXY_SETTING = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_PROXY_SET_DIRECT: SXH_PROXY_SETTING = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_PROXY_SET_PROXY: SXH_PROXY_SETTING = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type SXH_SERVER_CERT_OPTION = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_SERVER_CERT_IGNORE_UNKNOWN_CA: SXH_SERVER_CERT_OPTION = 256i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_SERVER_CERT_IGNORE_WRONG_USAGE: SXH_SERVER_CERT_OPTION = 512i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_SERVER_CERT_IGNORE_CERT_CN_INVALID: SXH_SERVER_CERT_OPTION = 4096i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_SERVER_CERT_IGNORE_CERT_DATE_INVALID: SXH_SERVER_CERT_OPTION = 8192i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const SXH_SERVER_CERT_IGNORE_ALL_SERVER_ERRORS: SXH_SERVER_CERT_OPTION = 13056i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XHR_AUTH = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_AUTH_ALL: XHR_AUTH = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_AUTH_NONE: XHR_AUTH = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_AUTH_PROXY: XHR_AUTH = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XHR_CERT_ERROR_FLAG = u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_ERROR_REVOCATION_FAILED: XHR_CERT_ERROR_FLAG = 8388608u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_ERROR_UNKNOWN_CA: XHR_CERT_ERROR_FLAG = 16777216u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_ERROR_CERT_CN_INVALID: XHR_CERT_ERROR_FLAG = 33554432u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_ERROR_CERT_DATE_INVALID: XHR_CERT_ERROR_FLAG = 67108864u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_ERROR_ALL_SERVER_ERRORS: XHR_CERT_ERROR_FLAG = 125829120u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XHR_CERT_IGNORE_FLAG = u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_IGNORE_REVOCATION_FAILED: XHR_CERT_IGNORE_FLAG = 128u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_IGNORE_UNKNOWN_CA: XHR_CERT_IGNORE_FLAG = 256u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_IGNORE_CERT_CN_INVALID: XHR_CERT_IGNORE_FLAG = 4096u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_IGNORE_CERT_DATE_INVALID: XHR_CERT_IGNORE_FLAG = 8192u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CERT_IGNORE_ALL_SERVER_ERRORS: XHR_CERT_IGNORE_FLAG = 12672u32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XHR_COOKIE_FLAG = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_IS_SECURE: XHR_COOKIE_FLAG = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_IS_SESSION: XHR_COOKIE_FLAG = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_THIRD_PARTY: XHR_COOKIE_FLAG = 16i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_PROMPT_REQUIRED: XHR_COOKIE_FLAG = 32i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_EVALUATE_P3P: XHR_COOKIE_FLAG = 64i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_APPLY_P3P: XHR_COOKIE_FLAG = 128i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_P3P_ENABLED: XHR_COOKIE_FLAG = 256i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_IS_RESTRICTED: XHR_COOKIE_FLAG = 512i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_IE6: XHR_COOKIE_FLAG = 1024i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_IS_LEGACY: XHR_COOKIE_FLAG = 2048i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_NON_SCRIPT: XHR_COOKIE_FLAG = 4096i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_HTTPONLY: XHR_COOKIE_FLAG = 8192i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XHR_COOKIE_STATE = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_STATE_UNKNOWN: XHR_COOKIE_STATE = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_STATE_ACCEPT: XHR_COOKIE_STATE = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_STATE_PROMPT: XHR_COOKIE_STATE = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_STATE_LEASH: XHR_COOKIE_STATE = 3i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_STATE_DOWNGRADE: XHR_COOKIE_STATE = 4i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_COOKIE_STATE_REJECT: XHR_COOKIE_STATE = 5i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XHR_CRED_PROMPT = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CRED_PROMPT_ALL: XHR_CRED_PROMPT = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CRED_PROMPT_NONE: XHR_CRED_PROMPT = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_CRED_PROMPT_PROXY: XHR_CRED_PROMPT = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XHR_PROPERTY = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_NO_CRED_PROMPT: XHR_PROPERTY = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_NO_AUTH: XHR_PROPERTY = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_TIMEOUT: XHR_PROPERTY = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_NO_DEFAULT_HEADERS: XHR_PROPERTY = 3i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_REPORT_REDIRECT_STATUS: XHR_PROPERTY = 4i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_NO_CACHE: XHR_PROPERTY = 5i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_EXTENDED_ERROR: XHR_PROPERTY = 6i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_QUERY_STRING_UTF8: XHR_PROPERTY = 7i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_IGNORE_CERT_ERRORS: XHR_PROPERTY = 8i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_ONDATA_THRESHOLD: XHR_PROPERTY = 9i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_SET_ENTERPRISEID: XHR_PROPERTY = 10i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XHR_PROP_MAX_CONNECTIONS: XHR_PROPERTY = 11i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub type XMLELEM_TYPE = i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLELEMTYPE_ELEMENT: XMLELEM_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLELEMTYPE_TEXT: XMLELEM_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLELEMTYPE_COMMENT: XMLELEM_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLELEMTYPE_DOCUMENT: XMLELEM_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLELEMTYPE_DTD: XMLELEM_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLELEMTYPE_PI: XMLELEM_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub const XMLELEMTYPE_OTHER: XMLELEM_TYPE = 6i32;
#[repr(C)]
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub struct XHR_CERT {
    pub cbCert: u32,
    pub pbCert: *mut u8,
}
impl ::core::marker::Copy for XHR_CERT {}
impl ::core::clone::Clone for XHR_CERT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct XHR_COOKIE {
    pub pwszUrl: ::windows_sys::core::PWSTR,
    pub pwszName: ::windows_sys::core::PWSTR,
    pub pwszValue: ::windows_sys::core::PWSTR,
    pub pwszP3PPolicy: ::windows_sys::core::PWSTR,
    pub ftExpires: super::super::super::Foundation::FILETIME,
    pub dwFlags: u32,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for XHR_COOKIE {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for XHR_COOKIE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub struct XML_ERROR {
    pub _nLine: u32,
    pub _pchBuf: ::windows_sys::core::BSTR,
    pub _cchBuf: u32,
    pub _ich: u32,
    pub _pszFound: ::windows_sys::core::BSTR,
    pub _pszExpected: ::windows_sys::core::BSTR,
    pub _reserved1: u32,
    pub _reserved2: u32,
}
impl ::core::marker::Copy for XML_ERROR {}
impl ::core::clone::Clone for XML_ERROR {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Data_Xml_MsXml\"`*"]
pub struct __msxml6_ReferenceRemainingTypes__ {
    pub __tagDomNodeType__: DOMNodeType,
    pub __domNodeType__: DOMNodeType,
    pub __serverXmlHttpOptionEnum__: SERVERXMLHTTP_OPTION,
    pub __serverXmlHttpOption__: SERVERXMLHTTP_OPTION,
    pub __serverCertOptionEnum__: SXH_SERVER_CERT_OPTION,
    pub __serverCertOption__: SXH_SERVER_CERT_OPTION,
    pub __proxySettingEnum__: SXH_PROXY_SETTING,
    pub __proxySetting__: SXH_PROXY_SETTING,
    pub __somItemTypeEnum__: SOMITEMTYPE,
    pub __somItemType__: SOMITEMTYPE,
    pub __schemaUseEnum__: SCHEMAUSE,
    pub __schemaUse__: SCHEMAUSE,
    pub __schemaDerivationMethodEnum__: SCHEMADERIVATIONMETHOD,
    pub __schemaDerivationMethod__: SCHEMADERIVATIONMETHOD,
    pub __schemaContentTypeEnum__: SCHEMACONTENTTYPE,
    pub __schemaContentType__: SCHEMACONTENTTYPE,
    pub __schemaProcessContentsEnum__: SCHEMAPROCESSCONTENTS,
    pub __schemaProcessContents__: SCHEMAPROCESSCONTENTS,
    pub __schemaWhitespaceEnum__: SCHEMAWHITESPACE,
    pub __schemaWhitespace__: SCHEMAWHITESPACE,
    pub __schemaTypeVarietyEnum__: SCHEMATYPEVARIETY,
    pub __schemaTypeVariety__: SCHEMATYPEVARIETY,
}
impl ::core::marker::Copy for __msxml6_ReferenceRemainingTypes__ {}
impl ::core::clone::Clone for __msxml6_ReferenceRemainingTypes__ {
    fn clone(&self) -> Self {
        *self
    }
}
